metadata(version="0.1.2")

# Originally written by Paul Sokolovsky.

require("os")
require("tty")
require("select")

package("ucurses")
